****************************************************
Interface for the MUSE specific data (``mpdaf.drs``)
****************************************************

The ``mpdaf.drs`` package contains Python interfaces for the MUSE pipeline's
objects.

Contents:

.. toctree::
   :maxdepth: 2

   pixtable
   rawfile


Reference/API
=============

.. automodapi:: mpdaf.drs
   :no-main-docstr:
